#!/bin/bash
# Start MDM container

set -exou pipefail

# Check if this is an EAP machine
function check_is_eap {
    if [[ -f /opt/ap/EAP ]]; then
        EAP=1
    fi
}

# Get script dir
SCRIPT_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

# Is machine EAP or not
EAP=0

# Check if this is an EAP machine
check_is_eap

# Source environment variables for the machine to pass to MDM
if [[ -f /etc/profile.d/99-aplinux.sh ]]; then
    source /etc/profile.d/99-aplinux.sh
else
    source /etc/profile.d/ap.sh
fi

source ${SCRIPT_DIR}/mdm.env

#
# Set variables
#
# For Classic/PF use docker proxy
# For EAP we disable docker proxy
# APDOCKER_DOMAIN is set in from the systemd .service file
if [[ ${EAP} -eq 1 ]]; then
    APDOCKER_DOMAIN=""
fi

LINUX_GENEVA_REGISTRY="linuxgeneva-microsoft.azurecr.io${APDOCKER_DOMAIN}"
MDM_IMAGE="${LINUX_GENEVA_REGISTRY}/genevamdm:${AP_MDM_IMAGE_TAG}"
MDSD_SERVICE_NAME="apnginx"
MDM_SERVICE_NAME="apgenevamdm"
MDMSTATSD_SERVICE_NAME="apgenevamdmstatsd"
DATAROOT="/ap/data"
DATA_GENEVA="${DATAROOT}/aplinux_geneva"
MDM_DATA_DIR="${DATA_GENEVA}/mdm"
AP_TOOLS_DIR="/ap/app/aptools"

# Hide ACR creds from logs
set +x

# Pull a fresh ACR connection config every start
# We'll only capture stdout to ACR_CONNECTION_STRING, which will be empty on failure
ACR_CONNECTION_STRING=$(${AP_TOOLS_DIR}/apsecret_refresh_acr.py)
if [ $? -ne 0 ]
then
    echo "WARNING: Could not grab the most recent connection configuration for ACR."
fi

if [ -z "${ACR_CONNECTION_STRING}" ]
then
    echo "ERROR: Could not read the cached connection configuration for ACR."
    exit -1
fi

# Turn the connection string into an array
ACR_CONFIG=( ${ACR_CONNECTION_STRING} )
ACR_CLIENT_ID="${ACR_CONFIG[0]}"
ACR_CLIENT_KEY="${ACR_CONFIG[1]}"

if [ -z "${ACR_CLIENT_ID}" ] || [ -z "${ACR_CLIENT_KEY}" ]
then
    echo "ERROR: Invalid connection configuration cached for ACR."
    exit -1
fi

set -x

# Don't bother logging in and pulling the image if its already been done
if [[ "$(docker images -q ${MDM_IMAGE} 2> /dev/null)" == "" ]]
then
    # Login to aplinux registry and pull the image
    set +x
    docker login -u ${ACR_CLIENT_ID} -p ${ACR_CLIENT_KEY} ${LINUX_GENEVA_REGISTRY}
    set -x
    docker pull ${MDM_IMAGE}
    docker logout "${LINUX_GENEVA_REGISTRY}"
fi

# Pull a fresh set of MDM secrets every start
${AP_TOOLS_DIR}/apsecret_refresh_geneva_hot.py -d ${MDM_DATA_DIR}

# Get the MDM int or prod ENDPOINT URL to publish MDM metrics to (created by apsecret_refresh_geneva_hot.py)
source ${MDM_DATA_DIR}/mdm_vars.env

# Just in case the container was stopped but not removed (happens during a HardReboot),
# remove the old container. The old container holds a lock on the name that we'll need
# to get things up and running again.
! docker stop ${MDM_SERVICE_NAME} > /dev/null 2>&1
! docker rm -f ${MDM_SERVICE_NAME} > /dev/null 2>&1

# Get the container up and automatically clean it up on exit
docker run --rm --name=${MDM_SERVICE_NAME} -v ${MDM_DATA_DIR}:/tmp/geneva_mdm -v /var/etw --net=host --uts=host -e MDM_ACCOUNT -e METRIC_ENDPOINT -e MDM_LOG_LEVEL -e MDM_SSL_DIGEST ${MDM_IMAGE}
